@@ -1,15 +1,39 @@
 package Mail::DMARC::Report::Send::HTTP;
 {
-  $Mail::DMARC::Report::Send::HTTP::VERSION = '0.20130515';
+  $Mail::DMARC::Report::Send::HTTP::VERSION = '0.20130517';
 }
 use strict;
 use warnings;
 
 use Carp;
 #use Data::Dumper;
+use Net::HTTP;
 
 use parent 'Mail::DMARC::Base';
 
+sub post {
+    my ($self, $uri, $report, $gz) = @_;
+
+    carp "http send incomplete!";
+    return;
+
+# TODO: test
+## no critic (Unreachable)
+    my $ver = $Mail::DMARC::VERSION;
+    my $s = Net::HTTP->new(Host => $uri->host ) or croak $@;
+    $s->write_request(POST => $uri->path, 'User-Agent' => "Mail::DMARC/$ver");
+    my($code, $mess, %h) = $s->read_response_headers;
+
+    while (1) {
+        my $buf;
+        my $n = $s->read_entity_body($buf, 1024);
+        croak "read failed: $!" unless defined $n;
+        last unless $n;
+        print $buf;
+        return 1;
+    }
+    return 0;
+};
 
 1;
 # ABSTRACT: send DMARC reports via HTTP
@@ -23,7 +47,7 @@ Mail::DMARC::Report::Send::HTTP - send DMARC reports via HTTP
 
 =head1 VERSION
 
-version 0.20130515
+version 0.20130517
 
 =head1 12.2.2. HTTP
 
