@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::URI;
 {
-  $Mail::DMARC::Report::URI::VERSION = '0.20130515';
+  $Mail::DMARC::Report::URI::VERSION = '0.20130517';
 }
 use strict;
 use warnings;
@@ -20,7 +20,7 @@ sub parse {
     foreach my $raw ( split /,/, $str ) {
         my ($u, $size_f) = split /!/, $raw;
         my $bytes = $self->get_size_limit($size_f);
-        my $uri = URI->new($u);
+        my $uri = URI->new($u) or carp "can't parse URI from $u";
         if ( $uri->scheme eq 'mailto' && lc substr($u, 0, 7) eq 'mailto:' ) {
             push @valids, { max_bytes => $bytes, uri => $uri };
             next;
@@ -62,7 +62,7 @@ Mail::DMARC::Report::URI - a DMARC reporting URI
 
 =head1 VERSION
 
-version 0.20130515
+version 0.20130517
 
 =head1 DESCRIPTION
 
